==> moodle_1.3.1.orig.tar.gz: moodle/lang/en/workshop.php <==
<?PHP // $Id: workshop.php,v 1.22 2004/03/12 16:34:45 rkingdon Exp $ 
      // workshop.php - created with Moodle 1.2 development (2004013101)


$string['absent'] = 'Absent';
$string['accumulative'] = 'Accumulative';
$string['action'] = 'Action';
$string['addacomment'] = 'Add a Comment';
$string['afterdeadline'] = 'After Deadline: $a';
$string['agreetothisassessment'] = 'Agree to this Assessment';
$string['allgradeshaveamaximumof'] = 'All Grades have a Maximum of: $a';
$string['allowresubmit'] = 'Allow Resubmissions';
$string['alreadyinphase'] = 'Already in Phase $a';
$string['amendassessmentelements'] = 'Amend Assessment Elements';
$string['amendtitle'] = 'Amend Title';
$string['analysisofassessments'] = 'Analysis of Assessments';
$string['assess'] = 'Assess';
$string['assessedon'] = 'Assessed on $a';
$string['assessment'] = 'Assessment';
$string['assessmentby'] = 'Assessment by $a';
$string['assessmentdropped'] = 'Assessment Dropped';
$string['assessmentgrade'] = 'Assessment Grade: $a';
$string['assessmentnotyetagreed'] = 'Assessment not yet agreed';
$string['assessmentofresubmission'] = 'This is an Assessment of a revised piece of the work. <br />The form here has been filled with your previous grades and comments. <br />Please amend these after looking at the revised work.';
$string['assessmentofthissubmission'] = 'Assessment of this submission';
$string['assessments'] = 'Assessments';
$string['assessmentsareok'] = 'Assessments are OK';
$string['assessmentsby'] = 'Assessments by $a';
$string['assessmentsdone'] = 'Assessments Done';
$string['assessmentsexcluded'] = 'Number of Assessments excluded for this $a';
$string['assessmentsmustbeagreed'] = 'Assessments must be agreed';
$string['assessmentwasagreedon'] = 'Assessment was agreed on $a';
$string['assessor'] = 'Assessor';
$string['assessthissubmission'] = 'Assess this submission';
$string['assignmentnotinthecorrectphase'] = 'Assignment not in the Correct Phase';
$string['authorofsubmission'] = 'Author of Submission';
$string['averageerror'] = 'Average Error';
$string['awaitinggradingbyteacher'] = 'Awaiting Grading by $a';
$string['beforedeadline'] = 'Before Deadline: $a';
$string['calculationoffinalgrades'] = 'Calculation of Final Grades';
$string['closeassignment'] = 'Close Assignment';
$string['comment'] = 'Comment';
$string['commentby'] = 'Comment by';
$string['confirmdeletionofthisitem'] = 'Confirm Deletion of this $a';
$string['correct'] = 'Correct';
$string['criterion'] = 'Criterion';
$string['deadline'] = 'Deadline';
$string['deadlineis'] = 'The Deadline is $a';
$string['delete'] = 'Delete';
$string['deleting'] = 'Deleting';
$string['description'] = 'Description';
$string['detailsofassessment'] = 'Details of Assessment';
$string['disagreewiththisassessment'] = 'Disagree with this Assessment';
$string['displayoffinalgrades'] = 'Display of Final Grades';
$string['dontshowgrades'] = 'Don\'t Show Grades';
$string['edit'] = 'Edit';
$string['editacomment'] = 'Edit a Comment';
$string['editingassessmentelements'] = 'Editing Assessment Elements';
$string['element'] = 'Element';
$string['elementweight'] = 'Element Weight';
$string['errorbanded'] = 'Error Banded';
$string['errortable'] = 'Error Table';
$string['excellent'] = 'Excellent';
$string['excludingdroppedassessments'] = 'excluding dropped Assessments';
$string['expectederror'] = 'Expected Error Value if guessing: $a';
$string['feedbackgoeshere'] = 'Feedback goes here';
$string['generalcomment'] = 'General comment';
$string['good'] = 'Good';
$string['grade'] = 'Grade';
$string['gradeassessment'] = 'Grade Assessment';
$string['graded'] = 'Graded';
$string['gradedbyteacher'] = 'Graded by $a';
$string['gradeforassessments'] = 'Grade for Assessments';
$string['gradeforbias'] = 'Grade for Bias';
$string['gradeforreliability'] = 'Grade for Reliability';
$string['gradeforstudentsassessment'] = 'Grade for Student\'s Assessment';
$string['gradeforsubmission'] = 'Grade for Submission';
$string['gradeofsubmission'] = 'Grade of Submission: $a';
$string['gradetable'] = 'Grade Table';
$string['gradingstrategy'] = 'Grading Strategy';
$string['hidegradesbeforeagreement'] = 'Hide Grades before Agreement';
$string['hidenamesfromstudents'] = 'Hide Names from $a';
$string['includeteachersgrade'] = 'Include Teacher\'s Grade';
$string['incorrect'] = 'Incorrect';
$string['iteration'] = 'Iteration $a completed';
$string['leaguetable'] = 'League Table of Submitted Work';
$string['listassessments'] = 'List Assessments';
$string['listofallsubmissions'] = 'List of all Submissions';
$string['liststudentsassessments'] = 'List Student\'s Assessments';
$string['loadingforteacherassessments'] = 'Loading for $a Assessments';
$string['mail1'] = 'Your assignment \'$a\' has been assessed by';
$string['mail10'] = 'You can assess it in your workshop assignment ';
$string['mail2'] = 'The comments and grade can be seen in the Workshop Assignment \'$a\'';
$string['mail3'] = 'You can see it in your Workshop Assignment';
$string['mail4'] = 'A comment has been added to the assignment \'$a\' by';
$string['mail5'] = 'The new comment can be seen in the Workshop Assignment \'$a\'';
$string['mail6'] = 'Your assessment of the assignment \'$a\' has by reviewed';
$string['mail7'] = 'The comments given by the $a can be seen in the Workshop Assignment ';
$string['mail8'] = 'The assignment $a is a revised piece of work. ';
$string['mail9'] = 'Please assess it in the workshop assignment $a ';
$string['managingassignment'] = 'Managing the Assignment';
$string['maximumsize'] = 'Maximum Size';
$string['modulename'] = 'Workshop';
$string['modulenameplural'] = 'Workshops';
$string['movingtophase'] = 'Moving to Phase $a';
$string['namesnotshowntostudents'] = 'Names not shown to $a';
$string['newassessments'] = 'New Assessments';
$string['newgradings'] = 'New Gradings';
$string['newsubmissions'] = 'New Submissions';
$string['noassessments'] = 'No Assessments';
$string['noassessmentsdone'] = 'No Assessments Done';
$string['nosubmission'] = 'No Submission';
$string['nosubmissionsavailableforassessment'] = 'No Submissions available for assessment';
$string['notavailable'] = 'Not Available';
$string['noteonassessmentelements'] = 'Note that grading is broken down into a number of \'Assessment Elements\'.<BR>
	This makes the grading easier and more consistent. As teacher you must add these <BR>
	Elements before making the assignment available to students. This is done by<BR>
	clicking on the assignment in the course, if no elements are present you will be asked<BR>
	to add them. You can change the number of elements using the Edit Assignment screen,<BR>
	the elements themselves can be amended from the &quot;Managing Assessment&quot; screen. ';
$string['notgraded'] = 'Not Graded';
$string['notitlegiven'] = 'No Title Given';
$string['numberofassessmentelements'] = 'Number of Comments, Assessment Elements, Grade Bands, Criterion Statments or Categories in a Rubric';
$string['numberofassessments'] = 'Number of Assessments';
$string['numberofassessmentschanged'] = 'Number of Assessments Changed: $a';
$string['numberofassessmentsofstudentsubmissions'] = 'Number of Assessments of Student Submissions';
$string['numberofassessmentsofteachersexamples'] = 'Number of Assessments of Examples from Teacher';
$string['numberofentries'] = 'Number of Entries';
$string['numberofnegativeresponses'] = 'Number of Negative Responses';
$string['numberofsubmissions'] = 'Number of Submissions: $a';
$string['on'] = 'on $a';
$string['openassignment'] = 'Open Assignment';
$string['optionaladjustment'] = 'Optional Adjustment';
$string['optionforpeergrade'] = 'Option for Peer Grade';
$string['optionsusedinanalysis'] = 'Options used in Analysis';
$string['overallgrade'] = 'Overall Grade';
$string['overallocation'] = 'Over Allocation';
$string['overallpeergrade'] = 'Overall Peer Grade: $a';
$string['overallteachergrade'] = 'Overall Teacher Grade: $a';
$string['ownwork'] = 'Own Work';
$string['percentageofassessments'] = 'Percentage of Assessments to Drop';
$string['phase'] = 'Phase';
$string['phase1'] = 'Set Up Assignment';
$string['phase1short'] = 'Set Up';
$string['phase2'] = 'Allow $a Submissions';
$string['phase2short'] = 'Submissions';
$string['phase3'] = 'Allow $a Submissions and Assessments';
$string['phase3short'] = 'Both';
$string['phase4'] = 'Allow $a Assessments';
$string['phase4short'] = 'Assessments';
$string['phase5'] = 'Calculation of Final Grades';
$string['phase5short'] = 'Calculation';
$string['phase6'] = 'Show Final Grades';
$string['phase6short'] = 'Show Grades';
$string['pleaseassesstheseexamplesfromtheteacher'] = 'Please assess these Examples from the $a';
$string['pleaseassessthesestudentsubmissions'] = 'Please assess these $a Submissions';
$string['pleaseassessyoursubmissions'] = 'Please assess your Submission(s)';
$string['poor'] = 'Poor';
$string['present'] = 'Present';
$string['reasonforadjustment'] = 'Reason for Adjustment';
$string['reassess'] = 'Re-assess';
$string['repeatanalysis'] = 'Repeat Analysis';
$string['reply'] = 'Reply';
$string['returnto'] = 'Return to';
$string['returntosubmissionpage'] = 'Return to Submission Page';
$string['rubric'] = 'Rubric';
$string['savedok'] = 'Saved OK';
$string['saveleaguetableoptions'] = 'Save League Table Options';
$string['savemyassessment'] = 'Save my Assessment';
$string['savemycomment'] = 'Save my Comment';
$string['savemygrading'] = 'Save my Grading';
$string['saveoverallocation'] = 'Save Over Allocation Level';
$string['scale10'] = 'Score out of 10';
$string['scale100'] = 'Score out of 100';
$string['scale20'] = 'Score out of 20';
$string['scalecorrect'] = '2 point Correct/Incorrect scale';
$string['scaleexcellent4'] = '4 point Excellent/Very Poor scale';
$string['scaleexcellent5'] = '5 point Excellent/Very Poor scale';
$string['scaleexcellent7'] = '7 point Excellent/Very Poor scale';
$string['scalegood3'] = '3 point Good/Poor scale';
$string['scalepresent'] = '2 point Present/Absent scale';
$string['scaleyes'] = '2 point Yes/No scale';
$string['select'] = 'Select';
$string['selfassessment'] = 'Self Assessment';
$string['setoverallocation'] = 'Set Over Allocation Level';
$string['showgrades'] = 'Show Grades';
$string['specimenassessmentform'] = 'Specimen Assessment Form';
$string['standarddeviation'] = 'Standard deviation of Element $a:';
$string['standarddeviationnote'] = 'Elements with standard deviations of zero or very small values can distort the analysis.<br /> This Element has been excluded from the analysis.';
$string['studentassessments'] = '$a Assessments';
$string['studentgrades'] = '$a Grades';
$string['studentsubmissions'] = '$a Submissions';
$string['studentsubmissionsforassessment'] = '$a Student Submissions for Assessment';
$string['submission'] = 'Submission';
$string['submissions'] = 'Submissions';
$string['submissionsnolongerallowed'] = 'Submissions no longer allowed';
$string['submissionsused'] = '$a Submissions used in this table';
$string['submitassignment'] = 'Submit Assignment';
$string['submitassignmentusingform'] = 'Submit your Assignment using this Form';
$string['submitexampleassignment'] = 'Submit Example Assignment';
$string['submitrevisedassignment'] = 'Submit your Revised Assignment using this Form';
$string['submitted'] = 'Submitted';
$string['submittedby'] = 'Submitted by';
$string['suggestedgrade'] = 'Suggested Grade';
$string['teacherassessments'] = '$a Assessments';
$string['teacherscomment'] = 'Teacher\'s Comment';
$string['teachersgrade'] = 'Teacher\'s Grade';
$string['teachersubmissionsforassessment'] = '$a Teacher Submissions for Assessment';
$string['thegradeis'] = 'The Grade is $a';
$string['thereisfeedbackfromtheteacher'] = 'There is feadback from the $a';
$string['theseasessmentsaregradedbytheteacher'] = 'These Assessments are graded by the $a';
$string['timeassessed'] = 'Time Assessed';
$string['title'] = 'Title';
$string['typeofscale'] = 'Type of Scale';
$string['ungradedassessmentsofstudentsubmissions'] = '$a Ungraded Assessments of Student Submissions';
$string['ungradedassessmentsofteachersubmissions'] = '$a Ungraded Assessments of Teacher Submissions';
$string['verypoor'] = 'Very Poor';
$string['view'] = 'View';
$string['viewassessmentofteacher'] = 'View Assessment of $a';
$string['viewotherassessments'] = 'View other Assessments';
$string['warningonamendingelements'] = 'WARNING: There are submitted assessments. <BR>Do NOT change the number
 of elements, the scale types or the element weights.';
$string['weight'] = 'Weight';
$string['weightederrorcount'] = 'Weighted Error Count: $a';
$string['weightforbias'] = 'Weight for Bias';
$string['weightforgradingofassessments'] = 'Weight for Grading of Assessments';
$string['weightforpeerassessments'] = 'Weight for Peer Assessments';
$string['weightforreliability'] = 'Weight for Reliability';
$string['weightforteacherassessments'] = 'Weight for Teacher Assessments';
$string['weights'] = 'Weights';
$string['weightsusedforfinalgrade'] = 'Weights used for Final Grade';
$string['weightsusedforsubmissions'] = 'Weights used for Submissions';
$string['workshopagreedassessments'] = 'Workshop Agreed Assessments';
$string['workshopassessments'] = 'Workshop Assessments';
$string['workshopcomments'] = 'Workshop Comments';
$string['workshopfeedback'] = 'Workshop Feedback';
$string['workshopsubmissions'] = 'Workshop Submissions';
$string['yourassessments'] = 'Your Assessments';
$string['yourassessmentsofexamplesfromtheteacher'] = 'Your Assessments of Examples from the $a';
$string['yourfeedbackgoeshere'] = 'Your Feedback goes Here';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/en/workshop.php <==
<?php // $Id$ 
      // workshop.php - created with Moodle 1.2 development (2004013101)


$string['absent'] = 'Absent';
$string['accumulative'] = 'Accumulative';
$string['action'] = 'Action';
$string['addacomment'] = 'Add a Comment';
$string['addcomment'] = 'Add Comment';
$string['afterdeadline'] = 'After Deadline: $a';
$string['ago'] = "\$a ago";
$string['agrade'] = 'Assmnt<br />Grade';
$string['agreetothisassessment'] = 'Agree to this Assessment';
$string['allgradeshaveamaximumof'] = 'All Grades have a Maximum of: $a';
$string['allowresubmit'] = 'Allow Resubmissions';
$string['allsubmissions'] = 'All submissions';
$string['alreadyinphase'] = 'Already in Phase $a';
$string['amendassessmentelements'] = 'Amend Assessment Elements';
$string['amendtitle'] = 'Amend Title';
$string['analysis'] = 'Analysis';
$string['analysisofassessments'] = 'Analysis of Assessments';
$string['assess'] = 'Assess';
$string['assessedon'] = 'Assessed on $a';
$string['assessment'] = 'Assessment';
$string['assessmentby'] = 'Assessment by $a';
$string['assessmentdropped'] = 'Assessment Dropped';
$string['assessmentend'] = 'End of assessments';
$string['assessmentendevent'] = 'End of assessments for $a';
$string['assessmentgrade'] = 'Assessment Grade: $a';
$string['assessmentnotyetagreed'] = 'Assessment not yet agreed';
$string['assessmentnotyetgraded'] = 'Assessment not yet graded';
$string['assessmentof'] = 'Assessment of $a';
$string['assessmentofresubmission'] = 'This is an Assessment of a revised piece of the work. <br />The form here has been filled with your previous grades and comments. <br />Please amend these after looking at the revised work.';
$string['assessmentofthissubmission'] = 'Assessment of this submission';
$string['assessments'] = 'Assessments';
$string['assessmentsareok'] = 'Assessments are OK';
$string['assessmentsby'] = 'Assessments by $a';
$string['assessmentsdone'] = 'Assessments Done';
$string['assessmentsexcluded'] = 'Number of Assessments excluded for this $a';
$string['assessmentsmustbeagreed'] = 'Assessments must be agreed';
$string['assessmentstart'] = 'Start of assessments';
$string['assessmentstartevent'] = 'Start of assessments for $a';
$string['assessmentwasagreedon'] = 'Assessment was agreed on $a';
$string['assessor'] = 'Assessor';
$string['assessthissubmission'] = 'Assess this submission';
$string['assessthisassessment'] = 'Grade this assessment';
$string['assignmentnotinthecorrectphase'] = 'Assignment not in the Correct Phase';
$string['assmnts'] = 'Assessments';
$string['attachment'] = 'Attachment';
$string['attachments'] = 'Attachments';
$string['authorofsubmission'] = 'Author of Submission';
$string['automaticgradeforassessment'] = 'Automatic grade for assessment';
$string['averageerror'] = 'Average Error';
$string['awaitinggradingbyteacher'] = 'Awaiting Grading by $a';
$string['beforedeadline'] = 'Before Deadline: $a';
$string['by'] = 'submitted by';
$string['calculationoffinalgrades'] = 'Calculation of Final Grades';
$string['clearlateflag'] = "Clear Late Flag";
$string['closeassignment'] = 'Close Assignment';
$string['comment'] = 'Comment';
$string['commentbank'] = 'Comment Bank';
$string['commentby'] = 'Comment by';
$string['comparisonofassessments'] = "Comparison of Assessments";
$string['confirmdeletionofthisitem'] = 'Confirm Deletion of this $a';
$string['correct'] = 'Correct';
$string['count'] = 'Count';
$string['criterion'] = 'Criterion';
$string['currentphase'] = 'Current phase';
$string['date'] = 'Date';
$string['datestr'] = '%%d/%%m/%%y<br />%%H:%%M';
$string['deadline'] = 'Deadline for submission';
$string['deadlineis'] = 'The Deadline for submission is $a';
$string['delete'] = 'Delete';
$string['deleting'] = 'Deleting';
$string['description'] = 'Description';
$string['detailsofassessment'] = 'Details of Assessment';
$string['disagreewiththisassessment'] = 'Disagree with this Assessment';
$string['displayofgrades'] = 'Display of Grades';
$string['displayofcurrentgrades'] = 'Display of Current Grades';
$string['displayoffinalgrades'] = 'Display of Final Grades';
$string['dontshowgrades'] = 'Don\'t Show Grades';
$string['edit'] = 'Edit';
$string['editacomment'] = 'Edit a Comment';
$string['editingassessmentelements'] = 'Editing Assessment Elements';
$string['editsubmission'] = 'Edit Submission';
$string['element'] = 'Element';
$string['elementweight'] = 'Element Weight';
$string['enterpassword'] = "Enter Password";
$string['errorbanded'] = 'Error Banded';
$string['errortable'] = 'Error Table';
$string['examplesubmissions'] = 'Example Submissions';
$string['excellent'] = 'Excellent';
$string['excludingdroppedassessments'] = 'excluding dropped Assessments';
$string['expectederror'] = 'Expected Error Value if guessing: $a';
$string['fair'] = "Fair";
$string['feedbackgoeshere'] = 'Feedback goes here';
$string['firstname'] = 'First name';
$string['generalcomment'] = 'General comment';
$string['good'] = 'Good';
$string['grade'] = 'Grade';
$string['gradeassessment'] = 'Grade Assessment';
$string['graded'] = 'Graded';
$string['gradedbyteacher'] = 'Graded by $a';
$string['gradegiventoassessment'] = 'Grade given to Assessment';
$string['gradeforassessments'] = 'Grade for Assessments';
$string['gradeforbias'] = 'Grade for Bias';
$string['gradeforreliability'] = 'Grade for Reliability';
$string['gradeforstudentsassessment'] = 'Grade for Student\'s Assessment';
$string['gradeforsubmission'] = 'Grade for Submission';
$string['gradeofsubmission'] = 'Grade of Submission: $a';
$string['grades'] = 'Grades';
$string['gradesforassessmentsare'] = 'Grades for Assessments are out of $a';
$string['gradesforstudentsassessment'] = 'Grades for $a\'s Assessment';
$string['gradesforsubmissionsare'] = 'Grades for Submissions are out of $a';
$string['gradetable'] = 'Grade Table';
$string['gradingallassessments'] = 'Grading all Assessments';
$string['gradinggrade'] = 'Grading Grade';
$string['gradingstrategy'] = 'Grading Strategy';
$string['hidegradesbeforeagreement'] = 'Hide Grades before Agreement';
$string['hidenamesfromstudents'] = 'Hide Names from $a';
$string['includeteachersgrade'] = 'Include Teacher\'s Grade';
$string['incorrect'] = 'Incorrect';
$string['info'] = 'Info';
$string['invaliddates'] = 'The dates you have entered are not possible.<br />Use the browser\'s Back button to return to the form and correct the dates.';
$string['iteration'] = 'Iteration $a completed';
$string['lastname'] = 'Surname';
$string['lax'] = "Lax";
$string['leaguetable'] = 'League Table of Submitted Work';
$string['listassessments'] = 'List Assessments';
$string['listofallsubmissions'] = 'List of all Submissions';
$string['liststudentsassessments'] = 'List Student\'s Assessments';
$string['loadingforteacherassessments'] = 'Loading for $a Assessments';
$string['mail1'] = 'Your assignment \'$a\' has been assessed by';
$string['mail10'] = 'You can assess it in your workshop assignment '; //not used in 1.5
$string['mail2'] = 'The comments and grade can be seen in the Workshop Assignment \'$a\'.';
$string['mail3'] = 'You can see it in your Workshop Assignment'; //not used in 1.5
$string['mail4'] = 'A comment has been added to the assignment \'$a\' by';
$string['mail5'] = 'The new comment can be seen in the Workshop Assignment \'$a\'.';
$string['mail6'] = 'Your assessment of the assignment \'$a\' has been reviewed.'; //not used in 1.5
$string['mail7'] = 'The comments given by the $a can be seen in the Workshop Assignment '; //not used in 1.5
$string['mail8'] = 'The assignment $a is a revised piece of work. ';
$string['mail9'] = 'Please assess it in the workshop assignment \'$a\'.';
$string['managingassignment'] = 'Managing the Workshop';
$string['maximum'] = 'Maximum';
$string['maximumsize'] = 'Maximum Size';
$string['mean'] = 'Mean';
$string['minimum'] = 'Minimum';
$string['modulename'] = 'Workshop';
$string['modulenameplural'] = 'Workshops';
$string['movingtophase'] = 'Moving to Phase $a';
$string['namesnotshowntostudents'] = 'Names not shown to $a';
$string['newassessments'] = 'New Assessments';
$string['newattachment'] = 'New Attachment';
$string['newgradings'] = 'New Gradings';
$string['newsubmissions'] = 'New Submissions';
$string['noassessments'] = 'No Assessments';
$string['noassessmentsdone'] = 'No Assessments Done';
$string['noattachments'] = 'No Attachments';
$string['nosubmission'] = 'No Submission';
$string['nosubmissionsavailableforassessment'] = 'No Submissions available for assessment';
$string['notallowed'] = 'You are not allowed on this page at this time';
$string['notavailable'] = 'Not Available';
$string['notenoughexamplessubmitted'] = 'Not enough Examples submitted.';
$string['noteonassessmentelements'] = 'Note that grading is broken down into a number of \'Assessment Elements\'.<br />
    This makes the grading easier and more consistent. As teacher you must add these <br />
    Elements before making the assignment available to students. This is done by<br />
    clicking on the assignment in the course, if no elements are present you will be asked<br />
    to add them. You can change the number of elements using the Edit Assignment screen,<br />
    the elements themselves can be amended from the &quot;Managing Assessment&quot; screen. ';
$string['noteonstudentassessments'] = '{Grade from Student / Grading Grade for Assessment}';
$string['notgraded'] = 'Not Graded';
$string['notitle'] = 'No Title';
$string['notitlegiven'] = 'No Title Given';
$string['nowork'] = 'The submission period has now ended.<br />You have submitted no work.';
$string['numberofassessmentelements'] = 'Number of Comments, Assessment Elements, Grade Bands, Criterion Statments or Categories in a Rubric';
$string['numberofassessments'] = 'Number of Assessments';
$string['numberofassessmentschanged'] = 'Number of Assessments Changed: $a';
$string['numberofassessmentsdropped'] = 'Number of Assessments dropped: $a';
$string['numberofassessmentsofstudentsubmissions'] = 'Number of Assessments of Student Submissions';
$string['numberofassessmentsweighted'] = 'Number of Assessments (weighted): $a';
$string['numberofassessmentsofteachersexamples'] = 'Number of Assessments of Examples from Teacher';
$string['numberofattachments'] = 'Number of Attachments expected on Submissions';
$string['numberofentries'] = 'Number of Entries';
$string['numberofnegativeresponses'] = 'Number of Negative Responses';
$string['numberofsubmissions'] = 'Number of Submissions: $a';
$string['ograde'] = 'Total<br />Grade';
$string['on'] = 'on $a';
$string['openassignment'] = 'Open Assignment';
$string['optionaladjustment'] = 'Optional Adjustment';
$string['optionforpeergrade'] = 'Option for Peer Grade';
$string['optionsusedinanalysis'] = 'Options used in Analysis';
$string['overallgrade'] = 'Overall Grade';
$string['overallocation'] = 'Over Allocation';
$string['overallpeergrade'] = 'Overall Peer Grade: $a';
$string['overallteachergrade'] = 'Overall Teacher Grade: $a';
$string['ownwork'] = 'Own Work';
$string['passwordprotectedworkshop'] = "Password Protected Workshop";
$string['passmnts'] = 'Peer<br />Assessments';
$string['percentageofassessments'] = 'Percentage of Assessments to Drop';
$string['phase'] = 'Phase';
$string['phase0'] = 'Inactive';
$string['phase0short'] = 'Inactive';
$string['phase1'] = 'Set Up Assignment';
$string['phase1short'] = 'Set Up';
$string['phase2'] = 'Allow $a Submissions';
$string['phase2short'] = 'Submissions';
$string['phase3'] = 'Allow $a Submissions and Assessments';
$string['phase3short'] = 'Both';
$string['phase4'] = 'Allow $a Assessments';
$string['phase4short'] = 'Assessments';
$string['phase5'] = 'Show Final Grades';
$string['phase5short'] = 'Show Grades';
$string['pleaseassesstheseexamplesfromtheteacher'] = 'Please assess these Examples from the $a';
$string['pleaseassessthesestudentsubmissions'] = 'Please assess these $a Submissions';
$string['pleaseassessyoursubmissions'] = 'Please assess your Submission(s)';
$string['poor'] = 'Poor';
$string['present'] = 'Present';
$string['reasonforadjustment'] = 'Reason for Adjustment';
$string['reassess'] = 'Re-assess';
$string['regradestudentassessments'] = 'Re-grade Student Assessments';
$string['releaseteachergrades'] = 'Release Teacher Grades';
$string['removeallattachments'] = 'Remove All Attachments';
$string['repeatanalysis'] = 'Repeat Analysis';
$string['reply'] = 'Reply';
$string['returnto'] = 'Return to';
$string['returntosubmissionpage'] = 'Return to Submission Page';
$string['rubric'] = 'Rubric';
$string['savedok'] = 'Saved OK';
$string['saveleaguetableoptions'] = 'Save League Table Options';
$string['savemyassessment'] = 'Save my Assessment';
$string['savemycomment'] = 'Save my Comment';
$string['savemygrading'] = 'Save my Grading';
$string['savemysubmission'] = 'Save my Submission';
$string['saveoverallocation'] = 'Save Over Allocation Level';
$string['scale10'] = 'Score out of 10';
$string['scale100'] = 'Score out of 100';
$string['scale20'] = 'Score out of 20';
$string['scalecorrect'] = '2 point Correct/Incorrect scale';
$string['scaleexcellent4'] = '4 point Excellent/Very Poor scale';
$string['scaleexcellent5'] = '5 point Excellent/Very Poor scale';
$string['scaleexcellent7'] = '7 point Excellent/Very Poor scale';
$string['scalegood3'] = '3 point Good/Poor scale';
$string['scalepresent'] = '2 point Present/Absent scale';
$string['scaleyes'] = '2 point Yes/No scale';
$string['select'] = 'Select';
$string['selfassessment'] = 'Self Assessment';
$string['sgrade'] = 'Sbmsn<br />Grade';
$string['showdescription'] = 'Show Workshop Description';
$string['showgrades'] = 'Show Grades';
$string['showsubmission'] = 'Show Submission: $a';
$string['specimenassessmentform'] = 'Specimen Assessment Form';
$string['standarddeviation'] = 'Standard Deviation';
$string['standarddeviationofelement'] = 'Standard deviation of Element $a:';
$string['standarddeviationnote'] = 'Elements with standard deviations of zero or very small values can distort the analysis.<br /> This Element has been excluded from the analysis.';
$string['strict'] = "Strict";
$string['studentassessments'] = '$a Assessments';
$string['studentgrades'] = '$a Grades';
$string['studentsubmissions'] = '$a Submissions';
$string['studentsubmissionsforassessment'] = '$a Student Submissions for Assessment';
$string['submission'] = 'Submission';
$string['submissionend'] = 'End of submissions';
$string['submissionendevent'] = 'End of submissions for $a';
$string['submissions'] = 'Submissions';
$string['submissionsnolongerallowed'] = 'Submissions no longer allowed';
$string['submissionstart'] = 'Start of submissions';
$string['submissionstartevent'] = 'Start of submissions for $a';
$string['submissionsused'] = '$a Submissions used in this table';
$string['submitassignment'] = 'Submit Assignment';
$string['submitassignmentusingform'] = 'Submit your Assignment using this Form';
$string['submitexample'] = 'Submit Example';
$string['submitexampleassignment'] = 'Submit Example Assignment';
$string['submitrevisedassignment'] = 'Submit your Revised Assignment using this Form';
$string['submitted'] = 'Submitted';
$string['submittedby'] = 'Submitted by';
$string['suggestedgrade'] = 'Suggested Grade';
$string['tassmnt'] = 'Teacher<br />Assessment';
$string['teacherassessments'] = '$a Assessments';
$string['teachergradeforassessment'] = '$a grade for assessment';
$string['teacherscomment'] = 'Teacher\'s Comment';
$string['teachersgrade'] = 'Teacher\'s Grade';
$string['teachersubmissionsforassessment'] = '$a Teacher Submissions for Assessment';
$string['thegradeis'] = 'The Grade is $a';
$string['thegradeforthisassessmentis'] = 'The grade for this assessment is $a';
$string['theseasessmentsaregradedbytheteacher'] = 'These Assessments are graded by the $a';
$string['thisisadroppedassessment'] = 'This is a dropped Assessment.';
$string['timeassessed'] = 'Time Assessed';
$string['title'] = 'Submission Title';
$string['typeofscale'] = 'Type of Scale';
$string['unassessed'] = "\$a Unassessed";
$string['ungradedassessments'] = '$a Ungraded Assessments';
$string['ungradedassessmentsofstudentsubmissions'] = '$a Ungraded Assessments of Student Submissions';
$string['ungradedassessmentsofteachersubmissions'] = '$a Ungraded Assessments of Teacher Submissions';
$string['uploadsuccess'] = 'Upload Successful';
$string['usepassword'] = "Use Password";
$string['verylax'] = "Very Lax";
$string['verypoor'] = "Very Poor";
$string['verystrict'] = "Very Strict";
$string['view'] = 'View';
$string['viewassessment'] = 'View Assessment';
$string['viewassessmentofteacher'] = 'View Assessment of $a';
$string['viewotherassessments'] = 'View other Assessments';
$string['warningonamendingelements'] = 'WARNING: There are submitted assessments. <br />Do NOT change the number
 of elements, the scale types or the element weights.';
$string['weight'] = 'Weight';
$string['weightederrorcount'] = 'Weighted Error Count: $a';
$string['weightforbias'] = 'Weight for Bias';
$string['weightforgradingofassessments'] = 'Weight for Grading of Assessments';
$string['weightforpeerassessments'] = 'Weight for Peer Assessments';
$string['weightforreliability'] = 'Weight for Reliability';
$string['weightforteacherassessments'] = 'Weight for Teacher Assessments';
$string['weights'] = 'Weights';
$string['weightsusedforfinalgrade'] = 'Weights used for Final Grade';
$string['weightsusedforsubmissions'] = 'Weights used for Submissions';
$string['workshopagreedassessments'] = 'Workshop Agreed Assessments';
$string['workshopassessments'] = 'Workshop Assessments';
$string['workshopcomments'] = 'Workshop Comments';
$string['workshopfeedback'] = 'Workshop Feedback';
$string['workshopsubmissions'] = 'Workshop Submissions';
$string['wrongpassword'] = 'Incorrect password for this Workshop';
$string['yourassessments'] = 'Your assessments of work by your peers';
$string['yoursubmissions'] = 'Your Submissions';
$string['yourassessmentsofexamplesfromtheteacher'] = 'Your Assessments of Examples from the $a';
$string['yourfeedbackgoeshere'] = 'Your Feedback goes Here';

?>
